@@ -214,7 +214,7 @@ exchange_mapi_cal_util_fetch_attachments (ECalComponent *comp, GSList **attach_l
 
 		sfname = g_filename_from_uri (sfname_uri, NULL, NULL);
 		mapped_file = g_mapped_file_new (sfname, FALSE, &error);
-		filename = g_path_get_basename (sfname);
+		filename = g_strdup (g_strrstr (sfname, uid));
 
 		if (mapped_file && g_str_has_prefix (filename, uid)) {
 			ExchangeMAPIAttachment *attach_item;
@@ -253,7 +253,11 @@ exchange_mapi_cal_util_fetch_attachments (ECalComponent *comp, GSList **attach_l
 
 			*attach_list = g_slist_append (*attach_list, attach_item);
 
+#if GLIB_CHECK_VERSION(2,21,3)
+			g_mapped_file_unref (mapped_file);
+#else
 			g_mapped_file_free (mapped_file);
+#endif
 		} else {
 			g_debug ("Could not map %s: %s \n", sfname_uri, error->message);
 			g_error_free (error);
@@ -1022,6 +1026,8 @@ fetch_server_data_cb (FetchItemsCallbackData *item_data, gpointer data)
 
 	cbdata->comp = comp; 
 
+	exchange_mapi_util_free_recipient_list (&recipients);
+	
 	g_free (smid);
 	g_free (fileuri);
 	g_free (filename);
